import z3c.form

class IUserAndGroupSelectionWidget(z3c.form.interfaces.IWidget):
        """ UserAndGroupSelection widget marker for z3c.form
        """

class IUsersAndGroupsSelectionWidget(z3c.form.interfaces.IMultiWidget):
        """ UsersAndGroupsSelection widget marker for z3c.form
        """
